import skimage.io as io
import skimage.color as color
import matplotlib.pyplot as plt
from skimage.color import rgb2gray
import numpy as np
import math
from skimage import feature


def blur(image, filter_size):
    n_row, n_col, colors = image.shape
    blurred_image = np.zeros( (n_row, n_col, 3), dtype=np.uint8)
    for i in range(0,n_row):
        for j in range(0,n_col):
            left=max(0,i-filter_size)
            right=min(i+filter_size,n_row)
            bottom=max(0,j-filter_size)
            top=min(n_col,j+filter_size)
            blurred_image[i,j] = image[left:right,bottom:top,:].mean(axis=(0,1))         
    return blurred_image

def detect_edges(image):
    n_row, n_col, colors = image.shape
    edge_image = np.zeros( (n_row, n_col, 3), dtype=np.uint8)
    for i in range(1,n_row-1):
        for j in range(1,n_col-1):
            for c in range(3):
                Lx = float(image[i-1,j,c])-float(image[i+1,j,c])
                Ly = float(image[i,j-1,c])-float(image[i,j+1,c])
                gradient = math.sqrt(Lx**2+Ly**2)
                edge_image[i,j,c] = np.uint8(gradient)
    return edge_image

#image = io.imread("malaria.jpg")
image = io.imread("car.jpg")
n_row, n_col, colors = image.shape

blurred_image = blur(image,20)
io.imsave("car_blurred20.jpg",blurred_image)

#plt.imshow(blurred_image)
#plt.show()

edge = detect_edges(image)
edge2 = feature.canny(rgb2gray(image), sigma=5)
plt.imshow(edge2)
plt.show()
