import skimage.io as io
import skimage.color as color
import matplotlib.pyplot as plt
from skimage.color import rgb2gray
import numpy as np
import math
from skimage import feature

def detect_edges(image):
    n_row, n_col, colors = image.shape
    edge_image = np.zeros( (n_row,n_col,3), dtype=np.uint8)
    for i in range(1,n_row-1):
        for j in range(1,n_col-1):
            for c in range(3):
                
                # conversion to int needed to accommodate
                # for potentially negative values
                d_r=int(image[i-1,j,c])-int(image[i+1,j,c])
                d_c=int(image[i,j-1,c])-int(image[i,j+1,c])
                gradient = math.sqrt(d_r**2+d_c**2)
                
                # limit value to 255
                edge_image[i,j,c]=np.uint8(min(255,gradient))
    return edge_image


def detect_edges2(image, scaling=1):
    n_row, n_col, colors = image.shape
    edge_image = np.zeros( (n_row,n_col,3), dtype=np.uint8)
    for i in range(1,n_row-1):
        for j in range(1,n_col-1):
            for c in range(3):
                
                # conversion to int is needed to accommodate for 
                # potentially negative values
                Lx=int(image[i-1,j,c])-int(image[i+1,j,c])
                Ly=int(image[i,j-1,c])-int(image[i,j+1,c])
                gradient = math.sqrt(Lx**2+Ly**2)
                edge_image[i,j,c] = np.uint8(min(255,gradient*scaling))
    return edge_image

def blur(image, filter_size):
    n_row, n_col, colors = image.shape
    blurred_image = np.zeros( (n_row, n_col, colors), dtype=np.uint8)
    half_size=int(filter_size/2)
    for i in range(n_row):
        for j in range(n_col):
            # define the boundaries of window around (i,j)
            left=max(0,i-half_size)
            right=min(i+half_size,n_row)
            bot=max(0,j-half_size)
            top=min(n_col,j+half_size)
            
            # calculate average of RGB values in window
            blurred_image[i,j] = \
                image[left:right,bot:top,:].mean(axis=(0,1))  
            
    return blurred_image


image = io.imread("monkey.jpg")
image_blurred=blur(image,50)
#image_blurred=gaussian(image,sigma=10)

io.imsave("monkey_blurred_edges.jpg",image_blurred)

edge_image_blurred = detect_edges2(image_blurred,10)
io.imsave("monkey_blurred_edges.jpg",edge_image_blurred)



edge2_image = feature.canny(rgb2gray(image), sigma=5)
io.imsave("monkey_canny_edges.jpg",edge2_image)
