import skimage.io as io
import skimage.color as color
import matplotlib.pyplot as plt
from skimage.color import rgb2gray
import numpy as np
import math
from skimage import feature
from skimage.filters import gaussian

def blur(image, filter_size):
    n_row, n_col, colors = image.shape
    blurred_image = np.zeros( (n_row, n_col, colors), dtype=np.uint8)
    half_size=int(filter_size/2)
    for i in range(n_row):
        for j in range(n_col):
            # define the boundaries of window around (i,j)
            left=max(0,i-half_size)
            right=min(i+half_size,n_row)
            bot=max(0,j-half_size)
            top=min(n_col,j+half_size)
            
            # calculate average of RGB values in window
            blurred_image[i,j] = \
                image[left:right,bot:top,:].mean(axis=(0,1))  
            
    return blurred_image

def detect_edges(image):
    n_row, n_col, colors = image.shape
    edge_image = np.zeros( (n_row, n_col, 3), dtype=np.uint8)
    for i in range(1,n_row-1):
        for j in range(1,n_col-1):
            for c in range(3):
                Lx = float(image[i-1,j,c])-float(image[i+1,j,c])
                Ly = float(image[i,j-1,c])-float(image[i,j+1,c])
                gradient = math.sqrt(Lx**2+Ly**2)
                edge_image[i,j,c] = np.uint8(gradient)
    return edge_image

image = io.imread("car.jpg")
print(image.shape)

blurred_image = blur(image,40)
plt.imshow(blurred_image)
plt.show()

edge = detect_edges(image)
plt.imshow(edge)
plt.show()
